<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>DecoderSndFileFactory</name>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="119"/>
        <source>Sndfile Plugin</source>
        <translation>Sndfile 外掛</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="122"/>
        <source>PCM Files</source>
        <translation>PCM 檔案</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="225"/>
        <source>About Sndfile Audio Plugin</source>
        <translation>關於 Sndfile 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="226"/>
        <source>Qmmp Sndfile Audio Plugin</source>
        <translation>Qmmp Sndfile 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="227"/>
        <source>Compiled against</source>
        <translation>編譯依賴於</translation>
    </message>
    <message>
        <location filename="../decodersndfilefactory.cpp" line="228"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>撰寫：Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
